@@ -96,7 +96,7 @@ class CourseraDownloader(object):
             raise Exception("Failed to find csrf cookie")
 
         # call the authenticator url
-        LOGIN_FORM = {'email': self.username, 'password': self.password}
+        LOGIN_FORM = {'email': self.username, 'password': self.password, 'webrequest':'true'}
         s.headers['Referer'] = 'https://www.coursera.org'
         s.headers['X-CSRFToken'] = s.cookies.get('csrf_token')
         s.cookies['csrftoken'] = s.cookies.get('csrf_token')
@@ -582,7 +582,7 @@ def main():
     parser.add_argument("-mppl", dest='mppl', type=int, default=100,
                         help='Maximum length of filenames/dirs in a path (windows only)')
     parser.add_argument("-w", dest='wkfilter', type=str, default=None,
-                        help="Comma separted list of week numbers to download e.g., 1,3,8")
+                        help="Comma separted list of sequence/lesson/week numbers to download e.g., 1,3,8")
     args = parser.parse_args()
 
     # check the parser
